Release Notes
=============

The authoritative state for any known issue can be found in `GitHub issues <https://github.com/arista-eosplus/ztpserver/issues>`_.

.. toctree::
    :maxdepth: 2
    :titlesonly:

    ReleaseNotes1.1.rst



